@@ -19,10 +19,10 @@ import networkx as nx
 # This MOF RAC generator assumes that pymatgen is installed.                            #
 # Pymatgen is used to get the primitive cell.                                           #
 #########################################################################################
-from pymatgen.io.cif import CifParser
 
 
 def get_primitive(datapath, writepath):
+    from pymatgen.io.cif import CifParser
     s = CifParser(datapath, occupancy_tolerance=1).get_structures()[0]
     sprim = s.get_primitive_structure()
     sprim.to("cif", writepath)
@@ -83,7 +83,7 @@ def make_MOF_SBU_RACs(SBUlist, SBU_subgraph, molcif, depth, name,cell,anchoring_
                 """""""""
                 functional_atoms = []
                 for jj in range(len(temp_mol.graph)):
-                    if not jj in link_list:
+                    if jj not in link_list:
                         if not set({temp_mol.atoms[jj].sym}) & set({"C","H"}):
                             functional_atoms.append(jj)
         # At this point, we look at the cycles for the graph, then add atoms if they are part of a cycle
