@@ -19,7 +19,7 @@ try:
 except ImportError:
     import openbabel  # fallback to version 2
 from typing import Any, List, Dict, Tuple, Union, Optional
-from pkg_resources import resource_filename, Requirement
+from importlib_resources import files as resource_files
 
 from molSimplify.Classes.globalvars import (globalvars,
                                             romans)
@@ -34,8 +34,7 @@ def printgeoms():
     if globs.custom_path:
         f = globs.custom_path + "/Data/coordinations.dict"
     else:
-        f = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify/Data/coordinations.dict")
+        f = resource_files("molSimplify").joinpath("Data/coordinations.dict")
     with open(f, 'r') as f:
         s = f.read().splitlines()
     s = [_f for _f in s if _f]
@@ -64,8 +63,7 @@ def getgeoms():
     if globs.custom_path:
         f = globs.custom_path + "/Data/coordinations.dict"
     else:
-        f = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify/Data/coordinations.dict")
+        f = resource_files("molSimplify").joinpath("Data/coordinations.dict")
     with open(f, 'r') as f:
         s = f.read().splitlines()
     s = [_f for _f in s if _f]
@@ -117,12 +115,6 @@ def readdict(fname):
 
 
 def readdict_sub(fname):
-    # Constructor
-    #  @param self The object pointer
-    #  @param subname The name of the substrate
-    class substrate:
-        def __init__(self, subname):
-            self.subname = subname
     d = dict()
     with open(fname, 'r') as f:
         txt = f.read()
@@ -139,8 +131,7 @@ def readdict_sub(fname):
                     vv.append(vvs)
                 else:
                     vv += vvs
-            # dict keys are instances of the substrate class
-            d[substrate(key)] = vv
+            d[key] = vv
     return d
 
 # Get ligands in dictionary
@@ -164,8 +155,7 @@ def getlicores(flip: bool = True) -> Dict[str, Any]:
     if globs.custom_path:  # test if a custom path is used:
         licores_path = str(globs.custom_path).rstrip('/') + "/Ligands/ligands.dict"
     else:
-        licores_path = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify/Ligands/ligands.dict")
+        licores_path = resource_files("molSimplify").joinpath("Ligands/ligands.dict")
     licores = readdict(licores_path)
     if flip:
         for ligand in list(licores.keys()):
@@ -195,8 +185,7 @@ def getslicores() -> Dict[str, Any]:
         slicores_path = str(globs.custom_path).rstrip(
             '/') + "/Ligands/simple_ligands.dict"
     else:
-        slicores_path = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify/Ligands/simple_ligands.dict")
+        slicores_path = resource_files("molSimplify").joinpath("Ligands/simple_ligands.dict")
     slicores = readdict(slicores_path)
     return slicores
 
@@ -245,8 +234,7 @@ def getbcores() -> dict:
     if globs.custom_path:  # test if a custom path is used:
         bcores_path = str(globs.custom_path).rstrip('/') + "/Bind/bind.dict"
     else:
-        bcores_path = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify/Bind/bind.dict")
+        bcores_path = resource_files("molSimplify").joinpath("Bind/bind.dict")
     bcores = readdict(bcores_path)
     return bcores
 
@@ -275,8 +263,7 @@ def getmcores():
     if globs.custom_path:  # test if a custom path is used:
         mcores = str(globs.custom_path).rstrip('/') + "/Cores/cores.dict"
     else:
-        mcores = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify/Cores/cores.dict")
+        mcores = resource_files("molSimplify").joinpath("Cores/cores.dict")
     mcores = readdict(mcores)
     return mcores
 
@@ -306,8 +293,7 @@ def getsubcores():
         subcores = str(globs.custom_path).rstrip(
             '/') + "/Substrates/substrates.dict"
     else:
-        subcores = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify/Substrates/substrates.dict")
+        subcores = resource_files("molSimplify").joinpath("Substrates/substrates.dict")
     subcores = readdict_sub(subcores)
     return subcores
 
@@ -323,8 +309,7 @@ def loaddata(path: str) -> dict:
     if globs.custom_path:  # test if a custom path is used:
         fname = str(globs.custom_path).rstrip('/') + path
     else:
-        fname = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify"+path)
+        fname = resource_files("molSimplify").joinpath(path.strip('/'))
     d = dict()
 
     with open(fname) as f:
@@ -348,8 +333,7 @@ def loaddata_ts(path: str) -> dict:
     if globs.custom_path:  # test if a custom path is used:
         fname = str(globs.custom_path).rstrip('/') + path
     else:
-        fname = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify"+path)
+        fname = resource_files("molSimplify").joinpath(path.strip('/'))
     d = dict()
 
     with open(fname) as f:
@@ -452,8 +436,7 @@ def loadcoord(coord: str) -> List[List[float]]:
     if globs.custom_path:
         f = globs.custom_path + "/Data/" + coord + ".dat"
     else:
-        f = resource_filename(Requirement.parse(
-            "molSimplify"), "molSimplify/Data/" + coord + ".dat")
+        f = resource_files("molSimplify").joinpath(f"Data/{coord}.dat")
     with open(f) as f:
         txt = [_f for _f in f.read().splitlines() if _f]
     b = []
@@ -485,8 +468,7 @@ def core_load(usercore: str, mcores: Optional[dict] = None) -> Tuple[Union[mol3D
         if globs.custom_path:
             fcore = globs.custom_path + "/Cores/" + dbentry[0]
         else:
-            fcore = resource_filename(Requirement.parse(
-                "molSimplify"), "molSimplify/Cores/" + dbentry[0])
+            fcore = str(resource_files("molSimplify").joinpath(f"Cores/{dbentry[0]}"))
         # check if core xyz/mol file exists
         if not glob.glob(fcore):
             emsg = "We can't find the core structure file %s right now! Something is amiss. Exiting..\n" % fcore
@@ -582,8 +564,7 @@ def substr_load(usersubstrate: str,
         if globs.custom_path:
             fsubst = globs.custom_path + "/Substrates/" + var_list_sub_i[0]
         else:
-            fsubst = resource_filename(Requirement.parse(
-                "molSimplify"), "molSimplify/Substrates/" + var_list_sub_i[0])
+            fsubst = str(resource_files("molSimplify").joinpath(f"Substrates/{var_list_sub_i[0]}"))
         # check if substrate xyz/mol file exists
         if not glob.glob(fsubst):
             emsg = "We can't find the substrate structure file %s right now! Something is amiss. Exiting..\n" % fsubst
@@ -706,8 +687,7 @@ def lig_load(userligand: str, licores: Optional[dict] = None) -> Tuple[Any, str]
         if globs.custom_path:
             flig = globs.custom_path + "/Ligands/" + dbentry[0]
         else:
-            flig = resource_filename(Requirement.parse(
-                "molSimplify"), "molSimplify/Ligands/" + dbentry[0])
+            flig = str(resource_files("molSimplify").joinpath(f"Ligands/{dbentry[0]}"))
         # check if ligand xyz/mol file exists
         print(('looking for '+flig))
         if not os.path.isfile(flig):
@@ -753,7 +733,6 @@ def lig_load(userligand: str, licores: Optional[dict] = None) -> Tuple[Any, str]
             lig.ffopt = dbentry[4][0]
     # load from file
     elif ('.mol' in userligand or '.xyz' in userligand or '.smi' in userligand or '.sdf' in userligand):
-        # flig = resource_filename(Requirement.parse("molSimplify"),"molSimplify/" +userligand)
         if glob.glob(userligand):
             ftype = userligand.split('.')[-1]
             # try and catch error if conversion doesn't work
@@ -818,8 +797,7 @@ def bind_load(userbind: str, bindcores: dict) -> Tuple[Union[mol3D, None], bool,
         if globs.custom_path:
             fbind = globs.custom_path + "/Bind/" + bindcores[userbind][0]
         else:
-            fbind = resource_filename(Requirement.parse(
-                "molSimplify"), "molSimplify/Bind/" + bindcores[userbind][0])
+            fbind = str(resource_files("molSimplify").joinpath(f"Bind/{bindcores[userbind][0]}"))
         # check if bind xyz/mol file exists
         if not glob.glob(fbind):
             emsg = "We can't find the binding species structure file %s right now! Something is amiss. Exiting..\n" % fbind
@@ -903,8 +881,7 @@ def getinputargs(args, fname: str):
 
 
 def plugin_defs() -> str:
-    plugin_path = resource_filename(Requirement.parse(
-        "molSimplify"), "molSimplify/plugindefines_reference.txt")
+    plugin_path = str(resource_files("molSimplify").joinpath("plugindefines_reference.txt"))
     return plugin_path
 
 # def get_name(args,rootdir,core,ligname,bind = False,bsmi = False):
@@ -950,7 +927,7 @@ def plugin_defs() -> str:
 #  @return Complex name
 
 
-def name_complex(rootdir: str, core, geometry, ligs, ligoc, sernum,
+def name_complex(rootdir: str, core, geometry, ligs, ligoc, sernum: int,
                  args, nconf=False, sanity=False, bind=False, bsmi=False) -> str:
     # new version of the above, designed to
     # produce more human and machine-readable formats
@@ -1144,16 +1121,11 @@ def copy_to_custom_path():
     if not os.path.exists(globs.custom_path):
         os.makedirs(globs.custom_path)
     # copytree cannot overwrite, need to enusre directory does not exist already
-    core_dir = resource_filename(Requirement.parse(
-        "molSimplify"), "molSimplify/Cores")
-    li_dir = resource_filename(Requirement.parse(
-        "molSimplify"), "molSimplify/Ligands")
-    bind_dir = (resource_filename(
-        Requirement.parse("molSimplify"), "molSimplify/Bind"))
-    data_dir = (resource_filename(
-        Requirement.parse("molSimplify"), "molSimplify/Data"))
-    subs_dir = (resource_filename(Requirement.parse(
-        "molSimplify"), "molSimplify/Substrates"))
+    core_dir = resource_files("molSimplify").joinpath("Cores")
+    li_dir = resource_files("molSimplify").joinpath("Ligands")
+    bind_dir = resource_files("molSimplify").joinpath("Bind")
+    data_dir = resource_files("molSimplify").joinpath("Data")
+    subs_dir = resource_files("molSimplify").joinpath("Substrates")
     if os.path.exists(str(globs.custom_path).rstrip("/")+"/Cores"):
         print('Note: removing old molSimplify data')
         shutil.rmtree(str(globs.custom_path).rstrip("/")+"/Cores")
