@@ -1,6 +1,6 @@
 import numpy as np
 import joblib
-from pkg_resources import resource_filename, Requirement
+from importlib_resources import files as resource_files
 from molSimplify.python_nn.tf_ANN import (tf_ANN_excitation_prepare,
                                           load_normalization_data,
                                           data_normalize,
@@ -9,7 +9,7 @@ from molSimplify.python_nn.tf_ANN import (tf_ANN_excitation_prepare,
 
 def load_sklearn_model(predictor):
     key = get_key(predictor, suffix="model")
-    modelfile = resource_filename(Requirement.parse("molSimplify"), "molSimplify/sklearn_models/" + key + '.h5')
+    modelfile = resource_files("molSimplify").joinpath(f"sklearn_models/{key}.h5")
     loaded_model = joblib.load(modelfile)
     return loaded_model
 
